@@ -13,11 +13,12 @@
 # under the License.
 
 import json
-import logging
 
 from osc_lib.command import command
 from osc_lib import utils
+from oslo_log import log as logging
 
+from zaqarclient._i18n import _
 from zaqarclient.transport import errors
 
 
@@ -29,6 +30,7 @@ def _get_client(obj, parsed_args):
 class CreateQueue(command.ShowOne):
     """Create a queue"""
 
+    _description = _("Create a queue")
     log = logging.getLogger(__name__ + ".CreateQueue")
 
     def get_parser(self, prog_name):
@@ -47,9 +49,28 @@ class CreateQueue(command.ShowOne):
         return columns, utils.get_item_properties(data, columns)
 
 
+class OldCreateQueue(CreateQueue):
+    """Create a queue"""
+
+    _description = _("Create a queue")
+    # TODO(wanghao): Remove this class and ``queue create`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue create" instead.'))
+        return super(OldCreateQueue, self).take_action(parsed_args)
+
+
 class DeleteQueue(command.Command):
     """Delete a queue"""
 
+    _description = _("Delete a queue")
     log = logging.getLogger(__name__ + ".DeleteQueue")
 
     def get_parser(self, prog_name):
@@ -66,9 +87,28 @@ class DeleteQueue(command.Command):
         client.queue(queue_name).delete()
 
 
+class OldDeleteQueue(DeleteQueue):
+    """Delete a queue"""
+
+    _description = _("Delete a queue")
+    # TODO(wanghao): Remove this class and ``queue delete`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue delete" instead.'))
+        return super(OldDeleteQueue, self).take_action(parsed_args)
+
+
 class ListQueues(command.Lister):
     """List available queues"""
 
+    _description = _("List available queues")
     log = logging.getLogger(__name__ + ".ListQueues")
 
     def get_parser(self, prog_name):
@@ -81,26 +121,52 @@ class ListQueues(command.Lister):
             "--limit",
             metavar="<limit>",
             help="Page size limit")
+        parser.add_argument(
+            "--detailed",
+            action="store_true",
+            help="If show detailed information of queue")
 
         return parser
 
     def take_action(self, parsed_args):
         client = _get_client(self, parsed_args)
         kwargs = {}
+        columns = ["Name"]
         if parsed_args.marker is not None:
             kwargs["marker"] = parsed_args.marker
         if parsed_args.limit is not None:
             kwargs["limit"] = parsed_args.limit
+        if parsed_args.detailed is not None and parsed_args.detailed:
+            kwargs["detailed"] = parsed_args.detailed
+            columns.extend(["Metadata_Dict", "Href"])
 
         data = client.queues(**kwargs)
-        columns = ("Name", )
-        return (columns,
-                (utils.get_item_properties(s, columns) for s in data))
+        columns = tuple(columns)
+        return (columns, (utils.get_item_properties(s, columns) for s in data))
+
+
+class OldListQueues(ListQueues):
+    """List available queues"""
+
+    _description = _("List available queues")
+    # TODO(wanghao): Remove this class and ``queue list`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue list" instead.'))
+        return super(OldListQueues, self).take_action(parsed_args)
 
 
 class CheckQueueExistence(command.ShowOne):
     """Check queue existence"""
 
+    _description = _("Check queue existence")
     log = logging.getLogger(__name__ + ".CheckQueueExistence")
 
     def get_parser(self, prog_name):
@@ -121,9 +187,28 @@ class CheckQueueExistence(command.ShowOne):
         return columns, utils.get_dict_properties(data, columns)
 
 
+class OldQueueExistence(CheckQueueExistence):
+    """Check queue existence"""
+
+    _description = _("Check queue existence")
+    # TODO(wanghao): Remove this class and ``queue exists`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue exists" instead.'))
+        return super(OldQueueExistence, self).take_action(parsed_args)
+
+
 class SetQueueMetadata(command.Command):
     """Set queue metadata"""
 
+    _description = _("Set queue metadata")
     log = logging.getLogger(__name__ + ".SetQueueMetadata")
 
     def get_parser(self, prog_name):
@@ -156,9 +241,29 @@ class SetQueueMetadata(command.Command):
             metadata(new_meta=valid_metadata)
 
 
+class OldSetQueueMetadata(SetQueueMetadata):
+    """Set queue metadata"""
+
+    _description = _("Set queue metadata")
+    # TODO(wanghao): Remove this class and ``queue set metadata`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue set metadata" '
+                           'instead.'))
+        return super(OldSetQueueMetadata, self).take_action(parsed_args)
+
+
 class GetQueueMetadata(command.ShowOne):
     """Get queue metadata"""
 
+    _description = _("Get queue metadata")
     log = logging.getLogger(__name__ + ".GetQueueMetadata")
 
     def get_parser(self, prog_name):
@@ -182,9 +287,29 @@ class GetQueueMetadata(command.ShowOne):
         return columns, utils.get_dict_properties(data, columns)
 
 
+class OldGetQueueMetadata(GetQueueMetadata):
+    """Get queue metadata"""
+
+    _description = _("Get queue metadata")
+    # TODO(wanghao): Remove this class and ``queue get metadata`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue get metadata" '
+                           'instead.'))
+        return super(OldGetQueueMetadata, self).take_action(parsed_args)
+
+
 class GetQueueStats(command.ShowOne):
     """Get queue stats"""
 
+    _description = _("Get queue stats")
     log = logging.getLogger(__name__ + ".GetQueueStats")
 
     def get_parser(self, prog_name):
@@ -210,9 +335,29 @@ class GetQueueStats(command.ShowOne):
         return columns, utils.get_dict_properties(data, columns)
 
 
+class OldGetQueueStats(GetQueueStats):
+    """Get queue stats"""
+
+    _description = _("Get queue stats")
+    # TODO(wanghao): Remove this class and ``queue stats`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging queue stats" '
+                           'instead.'))
+        return super(OldGetQueueStats, self).take_action(parsed_args)
+
+
 class CreatePool(command.ShowOne):
     """Create a pool"""
 
+    _description = _("Create a pool")
     log = logging.getLogger(__name__ + ".CreatePool")
 
     def get_parser(self, prog_name):
@@ -231,9 +376,9 @@ class CreatePool(command.ShowOne):
             metavar="<pool_weight>",
             help="weight of the pool")
         parser.add_argument(
-            "--pool_group",
-            metavar="<pool_group>",
-            help="Group of the pool")
+            "--flavor",
+            metavar="<flavor>",
+            help="Flavor of the pool")
         parser.add_argument(
             "--pool_options",
             type=json.loads,
@@ -252,8 +397,8 @@ class CreatePool(command.ShowOne):
             'options': parsed_args.pool_options
         }
 
-        if parsed_args.pool_group:
-            kw_arg.update({'group': parsed_args.pool_group})
+        if parsed_args.flavor:
+            kw_arg.update({'flavor': parsed_args.flavor})
 
         data = client.pool(parsed_args.pool_name, **kw_arg)
 
@@ -261,13 +406,33 @@ class CreatePool(command.ShowOne):
             raise RuntimeError('Failed to create pool(%s).' %
                                parsed_args.pool_name)
 
-        columns = ('Name', 'Weight', 'URI', 'Group', 'Options')
+        columns = ('Name', 'Weight', 'URI', 'Flavor', 'Options')
         return columns, utils.get_item_properties(data, columns)
 
 
+class OldCreatePool(CreatePool):
+    """Create a pool"""
+
+    _description = _("Create a pool")
+    # TODO(wanghao): Remove this class and ``pool create`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging pool create" '
+                           'instead.'))
+        return super(OldCreatePool, self).take_action(parsed_args)
+
+
 class ShowPool(command.ShowOne):
     """Display pool details"""
 
+    _description = _("Display pool details")
     log = logging.getLogger(__name__ + ".ShowPool")
 
     def get_parser(self, prog_name):
@@ -284,13 +449,33 @@ class ShowPool(command.ShowOne):
 
         pool_data = client.pool(parsed_args.pool_name,
                                 auto_create=False).get()
-        columns = ('Name', 'Weight', 'URI', 'Group', 'Options')
+        columns = ('Name', 'Weight', 'URI', 'Flavor', 'Options')
         return columns, utils.get_dict_properties(pool_data, columns)
 
 
+class OldShowPool(ShowPool):
+    """Display pool details"""
+
+    _description = _("Display pool details")
+    # TODO(wanghao): Remove this class and ``pool show`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging pool show" '
+                           'instead.'))
+        return super(OldShowPool, self).take_action(parsed_args)
+
+
 class UpdatePool(command.ShowOne):
     """Update a pool attribute"""
 
+    _description = _("Update a pool attribute")
     log = logging.getLogger(__name__+".UpdatePool")
 
     def get_parser(self, prog_name):
@@ -309,9 +494,9 @@ class UpdatePool(command.ShowOne):
             metavar="<pool_weight>",
             help="Weight of the pool")
         parser.add_argument(
-            "--pool_group",
-            metavar="<pool_group>",
-            help="Group of the pool")
+            "--flavor",
+            metavar="<flavor>",
+            help="Flavor of the pool")
         parser.add_argument(
             "--pool_options",
             type=json.loads,
@@ -328,21 +513,41 @@ class UpdatePool(command.ShowOne):
             kw_arg["uri"] = parsed_args.pool_uri
         if parsed_args.pool_weight:
             kw_arg["weight"] = parsed_args.pool_weight
-        if parsed_args.pool_group:
-            kw_arg["group"] = parsed_args.pool_group
+        if parsed_args.flavor:
+            kw_arg["flavor"] = parsed_args.flavor
         if parsed_args.pool_options:
             kw_arg["options"] = parsed_args.pool_options
 
         pool_obj = client.pool(parsed_args.pool_name, auto_create=False)
         pool_obj.update(kw_arg)
         pool_data = pool_obj.get()
-        columns = ('Name', 'Weight', 'URI', 'Group', 'Options')
+        columns = ('Name', 'Weight', 'URI', 'Flavor', 'Options')
         return columns, utils.get_dict_properties(pool_data, columns)
 
 
+class OldUpdatePool(UpdatePool):
+    """Update a pool attribute"""
+
+    _description = _("Update a pool attribute")
+    # TODO(wanghao): Remove this class and ``pool update`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging pool update" '
+                           'instead.'))
+        return super(OldUpdatePool, self).take_action(parsed_args)
+
+
 class DeletePool(command.Command):
     """Delete a pool"""
 
+    _description = _("Delete a pool")
     log = logging.getLogger(__name__ + ".DeletePool")
 
     def get_parser(self, prog_name):
@@ -359,9 +564,29 @@ class DeletePool(command.Command):
         client.pool(pool_name, auto_create=False).delete()
 
 
+class OldDeletePool(DeletePool):
+    """Delete a pool"""
+
+    _description = _("Delete a pool")
+    # TODO(wanghao): Remove this class and ``pool delete`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging pool delete" '
+                           'instead.'))
+        return super(OldDeletePool, self).take_action(parsed_args)
+
+
 class ListPools(command.Lister):
     """List available Pools"""
 
+    _description = _("List available Pools")
     log = logging.getLogger(__name__ + ".ListPools")
 
     def get_parser(self, prog_name):
@@ -376,8 +601,7 @@ class ListPools(command.Lister):
             help="Page size limit")
         parser.add_argument(
             "--detailed",
-            type=bool,
-            metavar="<detailed>",
+            action="store_true",
             help="Detailed output")
 
         return parser
@@ -386,7 +610,7 @@ class ListPools(command.Lister):
         client = _get_client(self, parsed_args)
 
         kwargs = {}
-        columns = ["Name", "Weight", "URI", "Group"]
+        columns = ["Name", "Weight", "URI", "Flavor"]
         if parsed_args.marker is not None:
             kwargs["marker"] = parsed_args.marker
         if parsed_args.limit is not None:
@@ -401,9 +625,29 @@ class ListPools(command.Lister):
                 (utils.get_item_properties(s, columns) for s in data))
 
 
+class OldListPools(ListPools):
+    """List available Pools"""
+
+    _description = _("List available Pools")
+    # TODO(wanghao): Remove this class and ``pool list`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging pool list" '
+                           'instead.'))
+        return super(OldListPools, self).take_action(parsed_args)
+
+
 class UpdateFlavor(command.ShowOne):
     """Update a flavor's attributes"""
 
+    _description = _("Update a flavor's attributes")
     log = logging.getLogger(__name__+".UpdateFlavor")
 
     def get_parser(self, prog_name):
@@ -413,9 +657,9 @@ class UpdateFlavor(command.ShowOne):
             metavar="<flavor_name>",
             help="Name of the flavor")
         parser.add_argument(
-            "--pool_group",
-            metavar="<pool_group>",
-            help="Pool group the flavor sits on")
+            "--pool_list",
+            metavar="<pool_list>",
+            help="Pool list the flavor sits on")
         parser.add_argument(
             "--capabilities",
             metavar="<capabilities>",
@@ -427,13 +671,14 @@ class UpdateFlavor(command.ShowOne):
         self.log.debug("take_action(%s)" % parsed_args)
         client = self.app.client_manager.messaging
         kwargs = {}
-        if parsed_args.pool_group:
-            kwargs['pool'] = parsed_args.pool_group
+        if parsed_args.pool_list:
+            pool_list = parsed_args.pool_list.split(',')
+            kwargs['pool_list'] = pool_list
         if parsed_args.capabilities:
             kwargs['capabilities'] = json.loads(parsed_args.capabilities)
 
         flavor = client.flavor(parsed_args.flavor_name, auto_create=False)
-        columns = ('Name', 'Pool', 'Capabilities')
+        columns = ('Name', 'Pool_list', 'Capabilities')
         flavor.update(kwargs)
         flavor_data = flavor.get()
         return columns, utils.get_dict_properties(flavor_data, columns)
@@ -442,6 +687,7 @@ class UpdateFlavor(command.ShowOne):
 class CreateFlavor(command.ShowOne):
     """Create a pool flavor"""
 
+    _description = _("Create a pool flavor")
     log = logging.getLogger(__name__ + ".CreateFlavor")
 
     def get_parser(self, prog_name):
@@ -451,9 +697,9 @@ class CreateFlavor(command.ShowOne):
             metavar="<flavor_name>",
             help="Name of the flavor")
         parser.add_argument(
-            "pool_group",
-            metavar="<pool_group>",
-            help="Pool group for flavor")
+            "--pool_list",
+            metavar="<pool_list>",
+            help="Pool list for flavor")
         parser.add_argument(
             "--capabilities",
             metavar="<capabilities>",
@@ -467,23 +713,19 @@ class CreateFlavor(command.ShowOne):
         self.log.debug("take_action(%s)" % parsed_args)
 
         client = self.app.client_manager.messaging
-
-        # FIXME(flwang): For now, we still use `pool` though it's not really
-        # correct since it's representing `pool_group` actually. But given we
-        # will remove pool group soon and get a 1:n mapping for flavor:pool,
-        # so let's keep it as it's, just for now.
         kwargs = {'capabilities': parsed_args.capabilities}
         data = client.flavor(parsed_args.flavor_name,
-                             pool=parsed_args.pool_group,
+                             pool_list=parsed_args.pool_list,
                              **kwargs)
 
-        columns = ('Name', 'Pool', 'Capabilities')
+        columns = ('Name', 'Pool list', 'Capabilities')
         return columns, utils.get_item_properties(data, columns)
 
 
 class DeleteFlavor(command.Command):
-    """Delete a flavor"""
+    """Delete a pool flavor"""
 
+    _description = _("Delete a pool flavor")
     log = logging.getLogger(__name__ + ".DeleteFlavor")
 
     def get_parser(self, prog_name):
@@ -497,12 +739,13 @@ class DeleteFlavor(command.Command):
     def take_action(self, parsed_args):
         client = _get_client(self, parsed_args)
         flavor_name = parsed_args.flavor_name
-        client.flavor(flavor_name).delete()
+        client.flavor(flavor_name, auto_create=False).delete()
 
 
 class ShowFlavor(command.ShowOne):
-    """Display flavor details"""
+    """Display pool flavor details"""
 
+    _description = _("Display pool flavor details")
     log = logging.getLogger(__name__ + ".ShowFlavor")
 
     def get_parser(self, prog_name):
@@ -519,13 +762,14 @@ class ShowFlavor(command.ShowOne):
         client = self.app.client_manager.messaging
         flavor_data = client.flavor(parsed_args.flavor_name,
                                     auto_create=False).get()
-        columns = ('Name', 'Pool', 'Capabilities')
+        columns = ('Name', 'Pool list', 'Capabilities')
         return columns, utils.get_dict_properties(flavor_data, columns)
 
 
 class ListFlavors(command.Lister):
-    """List available flavors"""
+    """List available pool flavors"""
 
+    _description = _("List available pool flavors")
     log = logging.getLogger(__name__ + ".ListFlavors")
 
     def get_parser(self, prog_name):
@@ -540,9 +784,7 @@ class ListFlavors(command.Lister):
             help="Page size limit")
         parser.add_argument(
             "--detailed",
-            type=bool,
-            default=False,
-            metavar="<detailed>",
+            action="store_true",
             help="If show detailed capabilities of flavor")
         return parser
 
@@ -556,9 +798,10 @@ class ListFlavors(command.Lister):
             kwargs["marker"] = parsed_args.marker
         if parsed_args.limit is not None:
             kwargs["limit"] = parsed_args.limit
-
         data = client.flavors(**kwargs)
-        columns = ("Name", 'Pool', 'Capabilities')
+        columns = ("Name", 'Pool list')
+        if parsed_args.detailed:
+            columns = ("Name", 'Pool list', 'Capabilities')
         return (columns,
                 (utils.get_item_properties(s, columns) for s in data))
 
@@ -566,6 +809,7 @@ class ListFlavors(command.Lister):
 class CreateClaim(command.Lister):
     """Create claim and return a list of claimed messages"""
 
+    _description = _("Create claim and return a list of claimed messages")
     log = logging.getLogger(__name__ + ".CreateClaim")
 
     def get_parser(self, prog_name):
@@ -614,9 +858,29 @@ class CreateClaim(command.Lister):
                 (utils.get_item_properties(s, keys) for s in data))
 
 
+class OldCreateClaim(CreateClaim):
+    """Create claim and return a list of claimed messages"""
+
+    _description = _("Create claim and return a list of claimed messages")
+    # TODO(wanghao): Remove this class and ``claim create`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging claim create" '
+                           'instead.'))
+        return super(OldCreateClaim, self).take_action(parsed_args)
+
+
 class QueryClaim(command.Lister):
     """Display claim details"""
 
+    _description = _("Display claim details")
     log = logging.getLogger(__name__ + ".QueryClaim")
 
     def get_parser(self, prog_name):
@@ -638,15 +902,35 @@ class QueryClaim(command.Lister):
         queue = client.queue(parsed_args.queue_name, auto_create=False)
         keys = ("_id", "age", "ttl", "body")
         columns = ("Message_ID", "Age", "TTL", "Message")
-        data = queue.claim(id=parsed_args.claim_id)._get()
+        data = queue.claim(id=parsed_args.claim_id)
 
         return (columns,
                 (utils.get_item_properties(s, keys) for s in data))
 
 
+class OldQueryClaim(QueryClaim):
+    """Display claim details"""
+
+    _description = _("Display claim details")
+    # TODO(wanghao): Remove this class and ``claim query`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging claim query" '
+                           'instead.'))
+        return super(OldQueryClaim, self).take_action(parsed_args)
+
+
 class RenewClaim(command.Lister):
     """Renew a claim"""
 
+    _description = _("Renew a claim")
     log = logging.getLogger(__name__ + ".RenewClaim")
 
     def get_parser(self, prog_name):
@@ -684,7 +968,7 @@ class RenewClaim(command.Lister):
 
         claim_obj = queue.claim(id=parsed_args.claim_id)
         claim_obj.update(**kwargs)
-        data = claim_obj._get()
+        data = claim_obj
         keys = ("_id", "age", "ttl", "body")
         columns = ("Message_ID", "Age", "TTL", "Message")
 
@@ -692,9 +976,29 @@ class RenewClaim(command.Lister):
                 (utils.get_item_properties(s, keys) for s in data))
 
 
+class OldRenewClaim(RenewClaim):
+    """Renew a claim"""
+
+    _description = _("Renew a claim")
+    # TODO(wanghao): Remove this class and ``claim renew`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging claim renew" '
+                           'instead.'))
+        return super(OldRenewClaim, self).take_action(parsed_args)
+
+
 class ReleaseClaim(command.Command):
     """Delete a claim"""
 
+    _description = _("Delete a claim")
     log = logging.getLogger(__name__ + ".ReleaseClaim")
 
     def get_parser(self, prog_name):
@@ -715,3 +1019,22 @@ class ReleaseClaim(command.Command):
 
         queue = client.queue(parsed_args.queue_name, auto_create=False)
         queue.claim(id=parsed_args.claim_id).delete()
+
+
+class OldReleaseClaim(ReleaseClaim):
+    """Delete a claim"""
+
+    _description = _("Delete a claim")
+    # TODO(wanghao): Remove this class and ``claim release`` command
+    #                after Queen.
+
+    # This notifies cliff to not display the help for this command
+    deprecated = True
+
+    log = logging.getLogger('deprecated')
+
+    def take_action(self, parsed_args):
+        self.log.warning(_('This command has been deprecated. '
+                           'Please use "messaging claim release" '
+                           'instead.'))
+        return super(OldReleaseClaim, self).take_action(parsed_args)
